nlptools.arabiner
=================


.. automodule:: nlptools.arabiner
   :members:
   :undoc-members:
   :show-inheritance:


.. toctree::
   :maxdepth: 1
   :caption: Modules:

   arabiner/bin/infer
